@@ -900,7 +900,10 @@ class WordToken(models.Model):
         prev_context = self.getPreviousContext()
         total_syllables = float(sum([x.getNumSylls() for x in prev_context]))
         total_seconds = float(sum([x.getDuration() for x in prev_context]))
-        rate = total_syllables / total_seconds
+        if total_seconds != 0.0:
+            rate = total_syllables / total_seconds
+        else:
+            rate = 0.0
         return rate
 
     def getFollowingSpeakingRate(self):
@@ -909,7 +912,10 @@ class WordToken(models.Model):
         foll_context = self.getFollowingContext()
         total_syllables = float(sum([x.getNumSylls() for x in foll_context]))
         total_seconds = float(sum([x.getDuration() for x in foll_context]))
-        rate = total_syllables / total_seconds
+        if total_seconds != 0.0:
+            rate = total_syllables / total_seconds
+        else:
+            rate = 0.0
         return rate
 
     def getPreviousCondProb(self):
