@@ -74,12 +74,13 @@ def doReset(logfilename):
 def combineResults(allout):
     if not os.path.isdir(fetch_media_resource("Results/Buckeye")):
         os.mkdir(fetch_media_resource("Results/Buckeye"))
+    head = allout[0][0].keys()
     with open(fetch_media_resource("Results/Buckeye/analysis.txt"),'w') as f:
-        f.write("\t".join(allout[0][0].keys()))
+        f.write("\t".join(head))
         f.write("\n")
         for l in allout:
             for line in l:
-                f.write("\t".join(map(str,line.values())))
+                f.write("\t".join([ str(line[x]) for x in head]))
                 f.write("\n")
 
 @task()
